<?php

namespace Drupal\commerce_from_price\Plugin\Field\FieldFormatter;

use Drupal\commerce_price\Plugin\Field\FieldFormatter\PriceDefaultFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Language\LanguageInterface;

/**
 * Plugin implementation of the 'commerce_from_price_default' formatter.
 *
 * @FieldFormatter(
 *   id = "commerce_from_price_default",
 *   label = @Translation("Default 'from' price"),
 *   field_types = {
 *     "entity_reference"
 *   }
 * )
 */
class FromPriceDefaultFormatter extends PriceDefaultFormatter {

  use FromPriceFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];

    $entities = $this->getPurchasableEntities($items);
    if (!$entities) {
      return $element;
    }

    $entity = $this->getLowestPricedEntity($entities);
    $lowest_price = $entity->getPrice();

    // If requested, consider multiple equal prices as a single price.
    $multiple = !($this->validateEqualPrices($entities) && $this->getSetting('process_equal_prices_as_single')) && $items->count() > 1;

    // Display the lowest price with the appropriate currency.
    $element = [
      '#theme' => 'commerce_from_price',
      '#label_before' => $multiple
        ? $this->getSetting('multiple_entities')['label_before']
        : $this->getSetting('single_entity')['label_before'],
      '#price' => $this->currencyFormatter->format(
        $lowest_price->getNumber(),
        $lowest_price->getCurrencyCode(),
        $this->getFormattingOptions()
      ),
      '#label_after' => $multiple
        ? $this->getSetting('multiple_entities')['label_after']
        : $this->getSetting('single_entity')['label_after'],
      '#cache' => [
        'contexts' => [
          'languages:' . LanguageInterface::TYPE_INTERFACE,
          'country',
        ],
      ],
    ];

    return $element;
  }

}
